package cicaprojekt;

import javax.swing.*;
import javax.swing.filechooser.FileNameExtensionFilter;
import java.awt.*;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.io.File;
import java.io.IOException;

public class ApplicationFrame implements Runnable
{
    private JFrame jframe;

    private JPanel mapselectorpanel;
    private Display gamepanel;

    private JList<File> filelist;

    private class ListMouseHandler extends MouseAdapter{
        @Override
        public void mouseClicked(MouseEvent e) {
            jframe.remove(mapselectorpanel);
            File dungeonSource = ((JList<File>) e.getComponent()).getSelectedValue();
            try {
                setGameParams(dungeonSource);
                gamepanel.drawVisuals();
            } catch (IOException e1) {
                Control.ioErrorMessage();
            }

            jframe.add(gamepanel);
            jframe.revalidate();
        }
    }

    public void init(){
        jframe = new JFrame();
        jframe.setFocusable(true);
        jframe.setMinimumSize(new Dimension(600, 400));
        jframe.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);

        initMapselector();

        jframe.add(mapselectorpanel);
    }

    public void backToMapSelection() {
        jframe.remove(gamepanel);
        initMapselector();
        jframe.add(mapselectorpanel);
        jframe.revalidate();
    }

    @Override
    public void run() {
        jframe.setVisible(true);
    }

    private void initMapselector() {
        mapselectorpanel = new JPanel();

        DefaultListModel<File> dungeonslist = new DefaultListModel<>();
        File dir = new File(System.getProperty("user.dir"));
        FileNameExtensionFilter filter = new FileNameExtensionFilter("N/A", "dungeon");

        for (File f : dir.listFiles()) {
            if (filter.accept(f) && f.isFile()){
                dungeonslist.addElement(f);
            }
        }

        filelist = new JList<>(dungeonslist);
        filelist.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        filelist.setLayoutOrientation(JList.HORIZONTAL_WRAP);
        filelist.addMouseListener(new ListMouseHandler());

        mapselectorpanel.add(filelist);
    }
    
    private void setGameParams(File dungeonFile) throws IOException {
        gamepanel = new Display();
        jframe.addKeyListener(new Control.KeyHandler());
        Game.instance.setDisplay(gamepanel);
        Game.instance.setDungeon(new Dungeon());
        Game.instance.startGame(dungeonFile);
    }
}
